@@ -31,7 +31,7 @@ def json_flatten(json_data,list_split_to_many=False,ignore_parent_key=None):
 
                 while check:
 
-                    if any(col_name + '_' in srchstr for srchstr in final_master.columns):
+                    if col_name.lower() != 'id' and any(col_name + '_' in srchstr for srchstr in final_master.columns):
                         master_flag = True
                         col_name_master = [col for col in final_master.columns if col_name + '_' in col]
 
@@ -71,10 +71,10 @@ def json_flatten(json_data,list_split_to_many=False,ignore_parent_key=None):
                                                 cols + '_'),
                                             how='left', on='temp_index')
                                     else:
-                                        drill_down_df = temp_df[~temp_df[cols].isna()].reset_index().join(
+                                        drill_down_df = temp_df[~temp_df[cols].isna()].reset_index().drop(cols, axis=1).join(
                                             pd.DataFrame(temp_df.loc[~temp_df[cols].isna(), cols].to_list())).set_index('index')
                                         final_master = final_master.join(
-                                            drill_down_df[list(set(drill_down_df.columns) - set(temp_df.columns))].add_prefix(
+                                            drill_down_df[list(set(drill_down_df.columns) - set(temp_df.drop(cols, axis=1).columns))].add_prefix(
                                                 cols + '_'),
                                             how='left')
                                         final_master['temp_index'] = final_master.reset_index().index
